==> nextcloud-29.0.9.tgz: nextcloud/apps/twofactor_backupcodes/l10n/ug.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "You created two-factor backup codes for your account" : "ھېساباتىڭىزغا ئىككى ئامىللىق زاپاسلاش كودى قۇردىڭىز",
    "Second-factor backup codes" : "ئىككىنچى ئامىل زاپاسلاش كودى",
    "Generate backup codes" : "زاپاسلاش كودى ھاسىل قىلىڭ",
    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "سىز ئىككى ئامىللىق دەلىللەشنى قوزغىدىڭىز ، ئەمما زاپاسلاش كودى ھاسىل قىلمىدىڭىز. ئۇلار ئىككىنچى ئامىلىڭىزنى يوقىتىپ قويسىڭىز ، ھېساباتىڭىزغا كىرىشنى ئەسلىگە كەلتۈرۈشكە موھتاج.",
    "Backup code" : "زاپاسلاش كودى",
    "Use backup code" : "زاپاسلاش كودىنى ئىشلىتىڭ",
    "Two factor backup codes" : "ئىككى ئامىل زاپاسلاش كودى",
    "A two-factor auth backup codes provider" : "ئىككى ئامىللىق ئاپتوماتىك زاپاسلاش كودى بىلەن تەمىنلىگۈچى",
    "Backup codes have been generated. {used} of {total} codes have been used." : "زاپاسلاش كودى بارلىققا كەلدى. {ئىشلىتىلگەن} ئومۇمىي} كودلار ئىشلىتىلگەن.",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later." : "بۇلار سىزنىڭ زاپاسلاش كودىڭىز. كېيىن كودلارنى قايتا ئوقۇيالمىغاچقا ساقلىۋېلىڭ ۋە ياكى بېسىڭ.",
    "Save backup codes" : "زاپاسلاش كودىنى ساقلاڭ",
    "Print backup codes" : "زاپاسلاش كودىنى بېسىڭ",
    "Regenerate backup codes" : "زاپاسلاش كودىنى قايتا ھاسىل قىلىڭ",
    "If you regenerate backup codes, you automatically invalidate old codes." : "زاپاسلاش كودىنى ئەسلىگە كەلتۈرسىڭىز ، كونا كودلارنى ئاپتوماتىك ئىناۋەتسىز قىلىسىز.",
    "An error occurred while generating your backup codes" : "زاپاسلاش كودىڭىزنى ھاسىل قىلغاندا خاتالىق كۆرۈلدى",
    "{name} backup codes" : "{name} زاپاسلاش كودى",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "ئىككى ئامىللىق دەلىللەشنى تەڭشىگەندە ساقلىغان زاپاسلاش كودىدىن بىرنى ئىشلىتىڭ.",
    "Submit" : "يوللاڭ",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "بۇلار سىزنىڭ زاپاسلاش كودىڭىز. كېيىن كودلارنى قايتا ئوقۇيالمىغاچقا ساقلىۋېلىڭ ۋە ياكى بېسىڭ"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-30.0.5.tgz: nextcloud/apps/twofactor_backupcodes/l10n/ug.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "You created two-factor backup codes for your account" : "ھېساباتىڭىزغا ئىككى ئامىللىق زاپاسلاش كودى قۇردىڭىز",
    "Second-factor backup codes" : "ئىككىنچى ئامىل زاپاسلاش كودى",
    "Generate backup codes" : "زاپاسلاش كودى ھاسىل قىلىڭ",
    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "سىز ئىككى ئامىللىق دەلىللەشنى قوزغىدىڭىز ، ئەمما زاپاسلاش كودى ھاسىل قىلمىدىڭىز. ئۇلار ئىككىنچى ئامىلىڭىزنى يوقىتىپ قويسىڭىز ، ھېساباتىڭىزغا كىرىشنى ئەسلىگە كەلتۈرۈشكە موھتاج.",
    "Backup code" : "زاپاسلاش كودى",
    "Use backup code" : "زاپاسلاش كودىنى ئىشلىتىڭ",
    "Two factor backup codes" : "ئىككى ئامىل زاپاسلاش كودى",
    "A two-factor auth backup codes provider" : "ئىككى ئامىللىق ئاپتوماتىك زاپاسلاش كودى بىلەن تەمىنلىگۈچى",
    "Backup codes have been generated. {used} of {total} codes have been used." : "زاپاسلاش كودى بارلىققا كەلدى. {used}{total} كودلار ئىشلىتىلگەن.",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later." : "بۇلار سىزنىڭ زاپاسلاش كودىڭىز. كېيىن كودلارنى قايتا ئوقۇيالمىغاچقا ساقلىۋېلىڭ ۋە ياكى بېسىڭ.",
    "Save backup codes" : "زاپاسلاش كودىنى ساقلاڭ",
    "Print backup codes" : "زاپاسلاش كودىنى بېسىڭ",
    "Regenerate backup codes" : "زاپاسلاش كودىنى قايتا ھاسىل قىلىڭ",
    "If you regenerate backup codes, you automatically invalidate old codes." : "زاپاسلاش كودىنى ئەسلىگە كەلتۈرسىڭىز ، كونا كودلارنى ئاپتوماتىك ئىناۋەتسىز قىلىسىز.",
    "An error occurred while generating your backup codes" : "زاپاسلاش كودىڭىزنى ھاسىل قىلغاندا خاتالىق كۆرۈلدى",
    "{name} backup codes" : "{name} زاپاسلاش كودى",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "ئىككى ئامىللىق دەلىللەشنى تەڭشىگەندە ساقلىغان زاپاسلاش كودىدىن بىرنى ئىشلىتىڭ.",
    "Submit" : "يوللاڭ",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "بۇلار سىزنىڭ زاپاسلاش كودىڭىز. كېيىن كودلارنى قايتا ئوقۇيالمىغاچقا ساقلىۋېلىڭ ۋە ياكى بېسىڭ"
},
"nplurals=2; plural=(n != 1);");
